@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Transport::SOAPHTTP;
 use vars '$VERSION';
-$VERSION = '2.05';
+$VERSION = '2.06';
 
 use base 'XML::Compile::Transport';
 
@@ -167,7 +167,8 @@ sub _prepare_call($)
 
     : sub  # real call
       { my $trace = $_[1];
-        $create_message->($_[0], $_[2]);
+print "REAL\n";
+        $create_message->($request, $_[0], $_[2]);
 
         $trace->{http_request}  = $request;
 
@@ -272,14 +273,14 @@ _CT
         }
 
         if($ct !~ m!start\=(["']?)\<([^"']*)\>\1!)
-        {   warning __x"cannot find root node in `{ct}'", ct => $ct;
+        {   warning __x"cannot find root node in content-type `{ct}'", ct=>$ct;
             return ();
         }
 
         my $startid = $2;
         my $root = delete $parts{$startid};
         unless(defined $root)
-        {   warning __x"cannot find root node id `{id}'", id => $startid;
+        {   warning __x"cannot find root node id in parts `{id}'",id=>$startid;
             return ();
         }
 
